==> baseui-9.45.0.tgz: package/esm/pagination/styled-components.js <==
function _objectSpread2(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018-2020 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import { styled } from '../styles/index.js';
export var StyledRoot = styled('div', function (_ref) {
  var $theme = _ref.$theme;
  return _objectSpread2({
    display: 'flex',
    alignItems: 'center',
    color: $theme.colors.backgroundInversePrimary
  }, $theme.typography.font350);
});
StyledRoot.displayName = "StyledRoot";
export var StyledMaxLabel = styled('span', function (_ref2) {
  var _ref3;

  var $theme = _ref2.$theme;
  return _ref3 = {}, _defineProperty(_ref3, $theme.direction === 'rtl' ? 'marginRight' : 'marginLeft', $theme.sizing.scale300), _defineProperty(_ref3, $theme.direction === 'rtl' ? 'marginLeft' : 'marginRight', $theme.sizing.scale600), _ref3;
});
StyledMaxLabel.displayName = "StyledMaxLabel";
export var StyledDropdownContainer = styled('div', function (_ref4) {
  var _ref5;

  var $theme = _ref4.$theme;
  return _ref5 = {
    position: 'relative'
  }, _defineProperty(_ref5, $theme.direction === 'rtl' ? 'marginRight' : 'marginLeft', $theme.sizing.scale600), _defineProperty(_ref5, $theme.direction === 'rtl' ? 'marginLeft' : 'marginRight', $theme.sizing.scale300), _ref5;
});
StyledDropdownContainer.displayName = "StyledDropdownContainer";

==> baseui-9.54.1.tgz: package/esm/pagination/styled-components.js <==
function _objectSpread2(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018-2020 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import { styled } from '../styles/index.js';
export var StyledRoot = styled('div', function (_ref) {
  var $theme = _ref.$theme;
  return _objectSpread2({
    display: 'flex',
    alignItems: 'center',
    color: $theme.colors.backgroundInversePrimary
  }, $theme.typography.font350);
});
StyledRoot.displayName = "StyledRoot";
export var StyledMaxLabel = styled('span', function (_ref2) {
  var _ref3;

  var $theme = _ref2.$theme;
  return _ref3 = {}, _defineProperty(_ref3, $theme.direction === 'rtl' ? 'marginRight' : 'marginLeft', $theme.sizing.scale300), _defineProperty(_ref3, $theme.direction === 'rtl' ? 'marginLeft' : 'marginRight', $theme.sizing.scale600), _ref3;
});
StyledMaxLabel.displayName = "StyledMaxLabel";
export var StyledDropdownContainer = styled('div', function (_ref4) {
  var _ref5;

  var $theme = _ref4.$theme,
      $isFocusVisible = _ref4.$isFocusVisible;
  return _ref5 = {
    position: 'relative',
    outline: $isFocusVisible ? "3px solid ".concat($theme.colors.accent) : 'none'
  }, _defineProperty(_ref5, $theme.direction === 'rtl' ? 'marginRight' : 'marginLeft', $theme.sizing.scale600), _defineProperty(_ref5, $theme.direction === 'rtl' ? 'marginLeft' : 'marginRight', $theme.sizing.scale300), _ref5;
});
StyledDropdownContainer.displayName = "StyledDropdownContainer";
